#! /usr/bin/env python

'''
Python Interface to SAGA Tools Library
----------
- Category : Terrain Analysis
- Name     : Lighting & Visibility
- ID       : ta_lighting

Description
----------
Lighting and visibility related analyses for digital terrain models.
'''

from PySAGA.helper import Tool_Wrapper

def Analytical_Hillshading(
    ELEVATION=None,
    SHADE=None,
    METHOD=None,
    POSITION=None,
    AZIMUTH=None,
    DECLINATION=None,
    DATE=None,
    TIME=None,
    EXAGGERATION=None,
    UNIT=None,
    SHADOW=None,
    NDIRS=None,
    RADIUS=None, Verbose=2):
    '''
    Analytical Hillshading
    ----------
    [ta_lighting.0]\n
    This tool performs an analytical hillshade computation for an elevation grid. The 'Standard' method simply calculates the angle at which light coming from the position of the light source would hit the surface. This method can produce angles greater than 90 degree. With the second method all values are kept within the range of 0-90 degree. It can be enhanced with shadowing effects, where shadowed cells will be marked with a value of exactly 90 degree. 'Shadows Only' creates a mask for the shadowed areas and sets all other cells to no-data. 'Combined Shading' takes the values of the standard method and multiplies these with the normalized slope. 'Ambient Occlusion' is based on the concepts of Tarini et al. (2006), but only the northern half-space is considered here.\n
    Arguments
    ----------
    - ELEVATION [`input grid`] : Elevation
    - SHADE [`output grid`] : Analytical Hillshading. The angle between the surface and the incoming light beams, measured in radians.
    - METHOD [`choice`] : Shading Method. Available Choices: [0] Standard [1] Limited Maximum [2] With Shadows [3] Shadows Only [4] Ambient Occlusion [5] Combined Shading Default: 0
    - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
    - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
    - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
    - DATE [`date`] : Day. Default: 2025-04-01
    - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
    - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
    - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
    - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow. The first is slightly faster but might show some artifacts.
    - NDIRS [`integer number`] : Number of Directions. Minimum: 2 Default: 8 Number of sample directions for ambient occlusion. Divides azimuth range (270 to 0 to 90 degree) into sectors. Declination (0 to 90 degree) is divided in (Number of Directions / 4) sectors.
    - RADIUS [`floating point number`] : Search Radius. Minimum: 0.001000 Default: 10.000000 Radius used to trace for shadows (ambient occlusion) [map units].

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '0', 'Analytical Hillshading')
    if Tool.is_Okay():
        Tool.Set_Input ('ELEVATION', ELEVATION)
        Tool.Set_Output('SHADE', SHADE)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('POSITION', POSITION)
        Tool.Set_Option('AZIMUTH', AZIMUTH)
        Tool.Set_Option('DECLINATION', DECLINATION)
        Tool.Set_Option('DATE', DATE)
        Tool.Set_Option('TIME', TIME)
        Tool.Set_Option('EXAGGERATION', EXAGGERATION)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('SHADOW', SHADOW)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('RADIUS', RADIUS)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_0(
    ELEVATION=None,
    SHADE=None,
    METHOD=None,
    POSITION=None,
    AZIMUTH=None,
    DECLINATION=None,
    DATE=None,
    TIME=None,
    EXAGGERATION=None,
    UNIT=None,
    SHADOW=None,
    NDIRS=None,
    RADIUS=None, Verbose=2):
    '''
    Analytical Hillshading
    ----------
    [ta_lighting.0]\n
    This tool performs an analytical hillshade computation for an elevation grid. The 'Standard' method simply calculates the angle at which light coming from the position of the light source would hit the surface. This method can produce angles greater than 90 degree. With the second method all values are kept within the range of 0-90 degree. It can be enhanced with shadowing effects, where shadowed cells will be marked with a value of exactly 90 degree. 'Shadows Only' creates a mask for the shadowed areas and sets all other cells to no-data. 'Combined Shading' takes the values of the standard method and multiplies these with the normalized slope. 'Ambient Occlusion' is based on the concepts of Tarini et al. (2006), but only the northern half-space is considered here.\n
    Arguments
    ----------
    - ELEVATION [`input grid`] : Elevation
    - SHADE [`output grid`] : Analytical Hillshading. The angle between the surface and the incoming light beams, measured in radians.
    - METHOD [`choice`] : Shading Method. Available Choices: [0] Standard [1] Limited Maximum [2] With Shadows [3] Shadows Only [4] Ambient Occlusion [5] Combined Shading Default: 0
    - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
    - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
    - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
    - DATE [`date`] : Day. Default: 2025-04-01
    - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
    - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
    - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
    - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow. The first is slightly faster but might show some artifacts.
    - NDIRS [`integer number`] : Number of Directions. Minimum: 2 Default: 8 Number of sample directions for ambient occlusion. Divides azimuth range (270 to 0 to 90 degree) into sectors. Declination (0 to 90 degree) is divided in (Number of Directions / 4) sectors.
    - RADIUS [`floating point number`] : Search Radius. Minimum: 0.001000 Default: 10.000000 Radius used to trace for shadows (ambient occlusion) [map units].

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '0', 'Analytical Hillshading')
    if Tool.is_Okay():
        Tool.Set_Input ('ELEVATION', ELEVATION)
        Tool.Set_Output('SHADE', SHADE)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('POSITION', POSITION)
        Tool.Set_Option('AZIMUTH', AZIMUTH)
        Tool.Set_Option('DECLINATION', DECLINATION)
        Tool.Set_Option('DATE', DATE)
        Tool.Set_Option('TIME', TIME)
        Tool.Set_Option('EXAGGERATION', EXAGGERATION)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('SHADOW', SHADOW)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('RADIUS', RADIUS)
        return Tool.Execute(Verbose)
    return False

def Potential_Incoming_Solar_Radiation(
    GRD_DEM=None,
    GRD_SVF=None,
    GRD_VAPOUR=None,
    GRD_LINKE=None,
    GRD_DIRECT=None,
    GRD_DIFFUS=None,
    GRD_TOTAL=None,
    GRD_RATIO=None,
    GRD_FLAT=None,
    GRD_DURATION=None,
    GRD_SUNRISE=None,
    GRD_SUNSET=None,
    GRD_VAPOUR_DEFAULT=None,
    GRD_LINKE_DEFAULT=None,
    SOLARCONST=None,
    LOCALSVF=None,
    UNITS=None,
    SHADOW=None,
    LOCATION=None,
    LATITUDE=None,
    PERIOD=None,
    DAY=None,
    DAY_STOP=None,
    DAYS_STEP=None,
    MOMENT=None,
    HOUR_RANGE=None,
    HOUR_STEP=None,
    METHOD=None,
    ATMOSPHERE=None,
    PRESSURE=None,
    WATER=None,
    DUST=None,
    LUMPED=None, Verbose=2):
    '''
    Potential Incoming Solar Radiation
    ----------
    [ta_lighting.2]\n
    Calculation of potential incoming solar radiation (insolation). Times of sunrise/sunset will only be calculated if time span is set to single day.\n
    Most options should do well, but TAPES-G based diffuse irradiance calculation ('Atmospheric Effects' methods 2 and 3) needs further revision!\n
    Arguments
    ----------
    - GRD_DEM [`input grid`] : Elevation
    - GRD_SVF [`optional input grid`] : Sky View Factor
    - GRD_VAPOUR [`optional input grid`] : Water Vapour Pressure [mbar]
    - GRD_LINKE [`optional input grid`] : Linke Turbidity Coefficient
    - GRD_DIRECT [`output grid`] : Direct Insolation
    - GRD_DIFFUS [`output grid`] : Diffuse Insolation
    - GRD_TOTAL [`output grid`] : Total Insolation
    - GRD_RATIO [`output grid`] : Direct to Diffuse Ratio
    - GRD_FLAT [`output grid`] : Compare to Flat Terrain
    - GRD_DURATION [`output grid`] : Duration of Insolation
    - GRD_SUNRISE [`output grid`] : Sunrise
    - GRD_SUNSET [`output grid`] : Sunset
    - GRD_VAPOUR_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 10.000000 default value if no grid has been selected
    - GRD_LINKE_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 3.000000 default value if no grid has been selected
    - SOLARCONST [`floating point number`] : Solar Constant [W/m²]. Minimum: 0.000000 Default: 1361.000000
    - LOCALSVF [`boolean`] : Local Sky View Factor. Default: 1 Use sky view factor based on local slope (after Oke 1988), if no sky viev factor grid is given.
    - UNITS [`choice`] : Units. Available Choices: [0] kWh/m² [1] kJ/m² [2] J/cm² Default: 0 Units for output radiation values.
    - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat [2] none Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow, or ignore shadowing effects. The first is slightly faster but might show some artifacts.
    - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
    - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
    - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
    - DAY [`date`] : Day. Default: 2025-04-01
    - DAY_STOP [`date`] : Last Day. Default: 2025-04-01
    - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
    - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
    - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
    - HOUR_STEP [`floating point number`] : Resolution [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 0.500000 Time step size for a day's calculation given in hours.
    - METHOD [`choice`] : Atmospheric Effects. Available Choices: [0] Height of Atmosphere and Vapour Pressure [1] Air Pressure, Water and Dust Content [2] Lumped Atmospheric Transmittance [3] Hofierka and Šúri Default: 2
    - ATMOSPHERE [`floating point number`] : Height of Atmosphere [m]. Minimum: 0.000000 Default: 12000.000000
    - PRESSURE [`floating point number`] : Barometric Pressure [mbar]. Minimum: 0.000000 Default: 1013.000000
    - WATER [`floating point number`] : Water Content [cm]. Minimum: 0.000000 Default: 1.680000 Water content of a vertical slice of atmosphere in cm: 1.5 to 1.7, average=1.68
    - DUST [`floating point number`] : Dust [ppm]. Minimum: 0.000000 Default: 100.000000 Dust factor: 100 ppm (standard)
    - LUMPED [`floating point number`] : Lumped Atmospheric Transmittance [Percent]. Minimum: 0.000000 Maximum: 100.000000 Default: 70.000000 The transmittance of the atmosphere, usually between 60 and 80 percent.

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '2', 'Potential Incoming Solar Radiation')
    if Tool.is_Okay():
        Tool.Set_Input ('GRD_DEM', GRD_DEM)
        Tool.Set_Input ('GRD_SVF', GRD_SVF)
        Tool.Set_Input ('GRD_VAPOUR', GRD_VAPOUR)
        Tool.Set_Input ('GRD_LINKE', GRD_LINKE)
        Tool.Set_Output('GRD_DIRECT', GRD_DIRECT)
        Tool.Set_Output('GRD_DIFFUS', GRD_DIFFUS)
        Tool.Set_Output('GRD_TOTAL', GRD_TOTAL)
        Tool.Set_Output('GRD_RATIO', GRD_RATIO)
        Tool.Set_Output('GRD_FLAT', GRD_FLAT)
        Tool.Set_Output('GRD_DURATION', GRD_DURATION)
        Tool.Set_Output('GRD_SUNRISE', GRD_SUNRISE)
        Tool.Set_Output('GRD_SUNSET', GRD_SUNSET)
        Tool.Set_Option('GRD_VAPOUR_DEFAULT', GRD_VAPOUR_DEFAULT)
        Tool.Set_Option('GRD_LINKE_DEFAULT', GRD_LINKE_DEFAULT)
        Tool.Set_Option('SOLARCONST', SOLARCONST)
        Tool.Set_Option('LOCALSVF', LOCALSVF)
        Tool.Set_Option('UNITS', UNITS)
        Tool.Set_Option('SHADOW', SHADOW)
        Tool.Set_Option('LOCATION', LOCATION)
        Tool.Set_Option('LATITUDE', LATITUDE)
        Tool.Set_Option('PERIOD', PERIOD)
        Tool.Set_Option('DAY', DAY)
        Tool.Set_Option('DAY_STOP', DAY_STOP)
        Tool.Set_Option('DAYS_STEP', DAYS_STEP)
        Tool.Set_Option('MOMENT', MOMENT)
        Tool.Set_Option('HOUR_RANGE', HOUR_RANGE)
        Tool.Set_Option('HOUR_STEP', HOUR_STEP)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('ATMOSPHERE', ATMOSPHERE)
        Tool.Set_Option('PRESSURE', PRESSURE)
        Tool.Set_Option('WATER', WATER)
        Tool.Set_Option('DUST', DUST)
        Tool.Set_Option('LUMPED', LUMPED)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_2(
    GRD_DEM=None,
    GRD_SVF=None,
    GRD_VAPOUR=None,
    GRD_LINKE=None,
    GRD_DIRECT=None,
    GRD_DIFFUS=None,
    GRD_TOTAL=None,
    GRD_RATIO=None,
    GRD_FLAT=None,
    GRD_DURATION=None,
    GRD_SUNRISE=None,
    GRD_SUNSET=None,
    GRD_VAPOUR_DEFAULT=None,
    GRD_LINKE_DEFAULT=None,
    SOLARCONST=None,
    LOCALSVF=None,
    UNITS=None,
    SHADOW=None,
    LOCATION=None,
    LATITUDE=None,
    PERIOD=None,
    DAY=None,
    DAY_STOP=None,
    DAYS_STEP=None,
    MOMENT=None,
    HOUR_RANGE=None,
    HOUR_STEP=None,
    METHOD=None,
    ATMOSPHERE=None,
    PRESSURE=None,
    WATER=None,
    DUST=None,
    LUMPED=None, Verbose=2):
    '''
    Potential Incoming Solar Radiation
    ----------
    [ta_lighting.2]\n
    Calculation of potential incoming solar radiation (insolation). Times of sunrise/sunset will only be calculated if time span is set to single day.\n
    Most options should do well, but TAPES-G based diffuse irradiance calculation ('Atmospheric Effects' methods 2 and 3) needs further revision!\n
    Arguments
    ----------
    - GRD_DEM [`input grid`] : Elevation
    - GRD_SVF [`optional input grid`] : Sky View Factor
    - GRD_VAPOUR [`optional input grid`] : Water Vapour Pressure [mbar]
    - GRD_LINKE [`optional input grid`] : Linke Turbidity Coefficient
    - GRD_DIRECT [`output grid`] : Direct Insolation
    - GRD_DIFFUS [`output grid`] : Diffuse Insolation
    - GRD_TOTAL [`output grid`] : Total Insolation
    - GRD_RATIO [`output grid`] : Direct to Diffuse Ratio
    - GRD_FLAT [`output grid`] : Compare to Flat Terrain
    - GRD_DURATION [`output grid`] : Duration of Insolation
    - GRD_SUNRISE [`output grid`] : Sunrise
    - GRD_SUNSET [`output grid`] : Sunset
    - GRD_VAPOUR_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 10.000000 default value if no grid has been selected
    - GRD_LINKE_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 3.000000 default value if no grid has been selected
    - SOLARCONST [`floating point number`] : Solar Constant [W/m²]. Minimum: 0.000000 Default: 1361.000000
    - LOCALSVF [`boolean`] : Local Sky View Factor. Default: 1 Use sky view factor based on local slope (after Oke 1988), if no sky viev factor grid is given.
    - UNITS [`choice`] : Units. Available Choices: [0] kWh/m² [1] kJ/m² [2] J/cm² Default: 0 Units for output radiation values.
    - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat [2] none Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow, or ignore shadowing effects. The first is slightly faster but might show some artifacts.
    - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
    - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
    - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
    - DAY [`date`] : Day. Default: 2025-04-01
    - DAY_STOP [`date`] : Last Day. Default: 2025-04-01
    - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
    - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
    - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
    - HOUR_STEP [`floating point number`] : Resolution [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 0.500000 Time step size for a day's calculation given in hours.
    - METHOD [`choice`] : Atmospheric Effects. Available Choices: [0] Height of Atmosphere and Vapour Pressure [1] Air Pressure, Water and Dust Content [2] Lumped Atmospheric Transmittance [3] Hofierka and Šúri Default: 2
    - ATMOSPHERE [`floating point number`] : Height of Atmosphere [m]. Minimum: 0.000000 Default: 12000.000000
    - PRESSURE [`floating point number`] : Barometric Pressure [mbar]. Minimum: 0.000000 Default: 1013.000000
    - WATER [`floating point number`] : Water Content [cm]. Minimum: 0.000000 Default: 1.680000 Water content of a vertical slice of atmosphere in cm: 1.5 to 1.7, average=1.68
    - DUST [`floating point number`] : Dust [ppm]. Minimum: 0.000000 Default: 100.000000 Dust factor: 100 ppm (standard)
    - LUMPED [`floating point number`] : Lumped Atmospheric Transmittance [Percent]. Minimum: 0.000000 Maximum: 100.000000 Default: 70.000000 The transmittance of the atmosphere, usually between 60 and 80 percent.

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '2', 'Potential Incoming Solar Radiation')
    if Tool.is_Okay():
        Tool.Set_Input ('GRD_DEM', GRD_DEM)
        Tool.Set_Input ('GRD_SVF', GRD_SVF)
        Tool.Set_Input ('GRD_VAPOUR', GRD_VAPOUR)
        Tool.Set_Input ('GRD_LINKE', GRD_LINKE)
        Tool.Set_Output('GRD_DIRECT', GRD_DIRECT)
        Tool.Set_Output('GRD_DIFFUS', GRD_DIFFUS)
        Tool.Set_Output('GRD_TOTAL', GRD_TOTAL)
        Tool.Set_Output('GRD_RATIO', GRD_RATIO)
        Tool.Set_Output('GRD_FLAT', GRD_FLAT)
        Tool.Set_Output('GRD_DURATION', GRD_DURATION)
        Tool.Set_Output('GRD_SUNRISE', GRD_SUNRISE)
        Tool.Set_Output('GRD_SUNSET', GRD_SUNSET)
        Tool.Set_Option('GRD_VAPOUR_DEFAULT', GRD_VAPOUR_DEFAULT)
        Tool.Set_Option('GRD_LINKE_DEFAULT', GRD_LINKE_DEFAULT)
        Tool.Set_Option('SOLARCONST', SOLARCONST)
        Tool.Set_Option('LOCALSVF', LOCALSVF)
        Tool.Set_Option('UNITS', UNITS)
        Tool.Set_Option('SHADOW', SHADOW)
        Tool.Set_Option('LOCATION', LOCATION)
        Tool.Set_Option('LATITUDE', LATITUDE)
        Tool.Set_Option('PERIOD', PERIOD)
        Tool.Set_Option('DAY', DAY)
        Tool.Set_Option('DAY_STOP', DAY_STOP)
        Tool.Set_Option('DAYS_STEP', DAYS_STEP)
        Tool.Set_Option('MOMENT', MOMENT)
        Tool.Set_Option('HOUR_RANGE', HOUR_RANGE)
        Tool.Set_Option('HOUR_STEP', HOUR_STEP)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('ATMOSPHERE', ATMOSPHERE)
        Tool.Set_Option('PRESSURE', PRESSURE)
        Tool.Set_Option('WATER', WATER)
        Tool.Set_Option('DUST', DUST)
        Tool.Set_Option('LUMPED', LUMPED)
        return Tool.Execute(Verbose)
    return False

def Sky_View_Factor(
    DEM=None,
    VISIBLE=None,
    SVF=None,
    SIMPLE=None,
    TERRAIN=None,
    DISTANCE=None,
    RADIUS=None,
    NDIRS=None,
    METHOD=None,
    DLEVEL=None, Verbose=2):
    '''
    Sky View Factor
    ----------
    [ta_lighting.3]\n
    Calculation of visible sky, sky view factor (SVF) and related parameters.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - VISIBLE [`output grid`] : Visible Sky. The unobstructed hemisphere given as percentage.
    - SVF [`output grid`] : Sky View Factor
    - SIMPLE [`output grid`] : Sky View Factor (Simplified)
    - TERRAIN [`output grid`] : Terrain View Factor
    - DISTANCE [`output grid`] : Average View Distance. Average distance to horizon.
    - RADIUS [`floating point number`] : Maximum Search Radius. Minimum: 0.000000 Default: 10000.000000 The maximum search radius [map units]. This value is ignored if set to zero.
    - NDIRS [`integer number`] : Number of Sectors. Minimum: 3 Default: 8
    - METHOD [`choice`] : Method. Available Choices: [0] cell size [1] multi scale Default: 0
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '3', 'Sky View Factor')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('VISIBLE', VISIBLE)
        Tool.Set_Output('SVF', SVF)
        Tool.Set_Output('SIMPLE', SIMPLE)
        Tool.Set_Output('TERRAIN', TERRAIN)
        Tool.Set_Output('DISTANCE', DISTANCE)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_3(
    DEM=None,
    VISIBLE=None,
    SVF=None,
    SIMPLE=None,
    TERRAIN=None,
    DISTANCE=None,
    RADIUS=None,
    NDIRS=None,
    METHOD=None,
    DLEVEL=None, Verbose=2):
    '''
    Sky View Factor
    ----------
    [ta_lighting.3]\n
    Calculation of visible sky, sky view factor (SVF) and related parameters.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - VISIBLE [`output grid`] : Visible Sky. The unobstructed hemisphere given as percentage.
    - SVF [`output grid`] : Sky View Factor
    - SIMPLE [`output grid`] : Sky View Factor (Simplified)
    - TERRAIN [`output grid`] : Terrain View Factor
    - DISTANCE [`output grid`] : Average View Distance. Average distance to horizon.
    - RADIUS [`floating point number`] : Maximum Search Radius. Minimum: 0.000000 Default: 10000.000000 The maximum search radius [map units]. This value is ignored if set to zero.
    - NDIRS [`integer number`] : Number of Sectors. Minimum: 3 Default: 8
    - METHOD [`choice`] : Method. Available Choices: [0] cell size [1] multi scale Default: 0
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '3', 'Sky View Factor')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('VISIBLE', VISIBLE)
        Tool.Set_Output('SVF', SVF)
        Tool.Set_Output('SIMPLE', SIMPLE)
        Tool.Set_Output('TERRAIN', TERRAIN)
        Tool.Set_Output('DISTANCE', DISTANCE)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        return Tool.Execute(Verbose)
    return False

def Topographic_Openness(
    DEM=None,
    POS=None,
    NEG=None,
    RADIUS=None,
    DIRECTIONS=None,
    DIRECTION=None,
    NDIRS=None,
    METHOD=None,
    DLEVEL=None,
    UNIT=None,
    NADIR=None, Verbose=2):
    '''
    Topographic Openness
    ----------
    [ta_lighting.5]\n
    Topographic openness expresses the dominance (positive) or enclosure (negative) of a landscape location. See Yokoyama et al. (2002) for a precise definition. Openness has been related to how wide a landscape can be viewed from any position. It has been proven to be a meaningful input for computer aided geomorphological mapping.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - POS [`output grid`] : Positive Openness
    - NEG [`output grid`] : Negative Openness
    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 Maximum search distance [map units].
    - DIRECTIONS [`choice`] : Directions. Available Choices: [0] single [1] all Default: 1
    - DIRECTION [`floating point number`] : Direction. Minimum: -360.000000 Maximum: 360.000000 Default: 315.000000 Single direction given as degree measured clockwise from the North direction.
    - NDIRS [`integer number`] : Number of Sectors. Minimum: 4 Default: 8
    - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000
    - UNIT [`choice`] : Unit. Available Choices: [0] Radians [1] Degree Default: 0
    - NADIR [`boolean`] : Difference from Nadir. Default: 1 If set, output angles are the mean difference from nadir, or else from a plane.

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '5', 'Topographic Openness')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('POS', POS)
        Tool.Set_Output('NEG', NEG)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('DIRECTIONS', DIRECTIONS)
        Tool.Set_Option('DIRECTION', DIRECTION)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('NADIR', NADIR)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_5(
    DEM=None,
    POS=None,
    NEG=None,
    RADIUS=None,
    DIRECTIONS=None,
    DIRECTION=None,
    NDIRS=None,
    METHOD=None,
    DLEVEL=None,
    UNIT=None,
    NADIR=None, Verbose=2):
    '''
    Topographic Openness
    ----------
    [ta_lighting.5]\n
    Topographic openness expresses the dominance (positive) or enclosure (negative) of a landscape location. See Yokoyama et al. (2002) for a precise definition. Openness has been related to how wide a landscape can be viewed from any position. It has been proven to be a meaningful input for computer aided geomorphological mapping.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - POS [`output grid`] : Positive Openness
    - NEG [`output grid`] : Negative Openness
    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 Maximum search distance [map units].
    - DIRECTIONS [`choice`] : Directions. Available Choices: [0] single [1] all Default: 1
    - DIRECTION [`floating point number`] : Direction. Minimum: -360.000000 Maximum: 360.000000 Default: 315.000000 Single direction given as degree measured clockwise from the North direction.
    - NDIRS [`integer number`] : Number of Sectors. Minimum: 4 Default: 8
    - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000
    - UNIT [`choice`] : Unit. Available Choices: [0] Radians [1] Degree Default: 0
    - NADIR [`boolean`] : Difference from Nadir. Default: 1 If set, output angles are the mean difference from nadir, or else from a plane.

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '5', 'Topographic Openness')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('POS', POS)
        Tool.Set_Output('NEG', NEG)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('DIRECTIONS', DIRECTIONS)
        Tool.Set_Option('DIRECTION', DIRECTION)
        Tool.Set_Option('NDIRS', NDIRS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('NADIR', NADIR)
        return Tool.Execute(Verbose)
    return False

def Visibility_Analysis(
    ELEVATION=None,
    POINTS=None,
    VISIBILITY=None,
    METHOD=None,
    UNIT=None,
    CUMULATIVE=None,
    NODATA=None,
    HEIGHT=None,
    HEIGHT_DEFAULT=None, Verbose=2):
    '''
    Visibility Analysis
    ----------
    [ta_lighting.6]\n
    This tool performs a visibility analysis using light source or observer points from a points layer.\n
    Arguments
    ----------
    - ELEVATION [`input grid`] : Elevation
    - POINTS [`input shapes`] : Points. Observer points.
    - VISIBILITY [`output grid`] : Visibility
    - METHOD [`choice`] : Output. Available Choices: [0] Visibility [1] Shade [2] Distance [3] Size Default: 3
    - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 1
    - CUMULATIVE [`boolean`] : Cumulative. Default: 0 If not set, output is the maximum size, or the cumulated sizes otherwise.
    - NODATA [`boolean`] : Ignore No-Data. Default: 0 Ignore elevations that have been marked as no-data.
    - HEIGHT [`table field`] : Height. Height of the light source or observer above ground.
    - HEIGHT_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 10.000000 default value if no attribute has been selected

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '6', 'Visibility Analysis')
    if Tool.is_Okay():
        Tool.Set_Input ('ELEVATION', ELEVATION)
        Tool.Set_Input ('POINTS', POINTS)
        Tool.Set_Output('VISIBILITY', VISIBILITY)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('CUMULATIVE', CUMULATIVE)
        Tool.Set_Option('NODATA', NODATA)
        Tool.Set_Option('HEIGHT', HEIGHT)
        Tool.Set_Option('HEIGHT_DEFAULT', HEIGHT_DEFAULT)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_6(
    ELEVATION=None,
    POINTS=None,
    VISIBILITY=None,
    METHOD=None,
    UNIT=None,
    CUMULATIVE=None,
    NODATA=None,
    HEIGHT=None,
    HEIGHT_DEFAULT=None, Verbose=2):
    '''
    Visibility Analysis
    ----------
    [ta_lighting.6]\n
    This tool performs a visibility analysis using light source or observer points from a points layer.\n
    Arguments
    ----------
    - ELEVATION [`input grid`] : Elevation
    - POINTS [`input shapes`] : Points. Observer points.
    - VISIBILITY [`output grid`] : Visibility
    - METHOD [`choice`] : Output. Available Choices: [0] Visibility [1] Shade [2] Distance [3] Size Default: 3
    - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 1
    - CUMULATIVE [`boolean`] : Cumulative. Default: 0 If not set, output is the maximum size, or the cumulated sizes otherwise.
    - NODATA [`boolean`] : Ignore No-Data. Default: 0 Ignore elevations that have been marked as no-data.
    - HEIGHT [`table field`] : Height. Height of the light source or observer above ground.
    - HEIGHT_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 10.000000 default value if no attribute has been selected

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '6', 'Visibility Analysis')
    if Tool.is_Okay():
        Tool.Set_Input ('ELEVATION', ELEVATION)
        Tool.Set_Input ('POINTS', POINTS)
        Tool.Set_Output('VISIBILITY', VISIBILITY)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('UNIT', UNIT)
        Tool.Set_Option('CUMULATIVE', CUMULATIVE)
        Tool.Set_Option('NODATA', NODATA)
        Tool.Set_Option('HEIGHT', HEIGHT)
        Tool.Set_Option('HEIGHT_DEFAULT', HEIGHT_DEFAULT)
        return Tool.Execute(Verbose)
    return False

def Potential_Annual_Insolation(
    DEM=None,
    INSOLATION=None,
    STEPS=None,
    UNITS=None,
    HOUR_STEP=None,
    YEAR=None, Verbose=2):
    '''
    Potential Annual Insolation
    ----------
    [ta_lighting.7]\n
    Calculates the annual potential total insolation for given time steps and stores resulting time series in a grid collection.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - INSOLATION [`output grid collection`] : Annual Insolation
    - STEPS [`integer number`] : Number of Steps. Minimum: 2 Maximum: 365 Default: 14 Number of time steps per year.
    - UNITS [`choice`] : Units. Available Choices: [0] kWh / m2 [1] kJ / m2 [2] J / cm2 Default: 0 Units for output radiation values.
    - HOUR_STEP [`floating point number`] : Resolution [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 0.500000 Time step size for a day's calculation given in hours.
    - YEAR [`integer number`] : Reference Year. Default: 2000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '7', 'Potential Annual Insolation')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('INSOLATION', INSOLATION)
        Tool.Set_Option('STEPS', STEPS)
        Tool.Set_Option('UNITS', UNITS)
        Tool.Set_Option('HOUR_STEP', HOUR_STEP)
        Tool.Set_Option('YEAR', YEAR)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_7(
    DEM=None,
    INSOLATION=None,
    STEPS=None,
    UNITS=None,
    HOUR_STEP=None,
    YEAR=None, Verbose=2):
    '''
    Potential Annual Insolation
    ----------
    [ta_lighting.7]\n
    Calculates the annual potential total insolation for given time steps and stores resulting time series in a grid collection.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - INSOLATION [`output grid collection`] : Annual Insolation
    - STEPS [`integer number`] : Number of Steps. Minimum: 2 Maximum: 365 Default: 14 Number of time steps per year.
    - UNITS [`choice`] : Units. Available Choices: [0] kWh / m2 [1] kJ / m2 [2] J / cm2 Default: 0 Units for output radiation values.
    - HOUR_STEP [`floating point number`] : Resolution [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 0.500000 Time step size for a day's calculation given in hours.
    - YEAR [`integer number`] : Reference Year. Default: 2000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '7', 'Potential Annual Insolation')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('INSOLATION', INSOLATION)
        Tool.Set_Option('STEPS', STEPS)
        Tool.Set_Option('UNITS', UNITS)
        Tool.Set_Option('HOUR_STEP', HOUR_STEP)
        Tool.Set_Option('YEAR', YEAR)
        return Tool.Execute(Verbose)
    return False

def Geomorphons(
    DEM=None,
    GEOMORPHONS=None,
    THRESHOLD=None,
    RADIUS=None,
    METHOD=None,
    DLEVEL=None, Verbose=2):
    '''
    Geomorphons
    ----------
    [ta_lighting.8]\n
    This tool derives so called geomorphons, which represent categories of terrain forms, from a digital elevation model using a machine vision approach.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - GEOMORPHONS [`output grid`] : Geomorphons
    - THRESHOLD [`floating point number`] : Threshold Angle. Minimum: 0.000000 Default: 1.000000 Flatness threshold angle (degrees).
    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 The radial limit (search radius) [map units].
    - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '8', 'Geomorphons')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('GEOMORPHONS', GEOMORPHONS)
        Tool.Set_Option('THRESHOLD', THRESHOLD)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_lighting_8(
    DEM=None,
    GEOMORPHONS=None,
    THRESHOLD=None,
    RADIUS=None,
    METHOD=None,
    DLEVEL=None, Verbose=2):
    '''
    Geomorphons
    ----------
    [ta_lighting.8]\n
    This tool derives so called geomorphons, which represent categories of terrain forms, from a digital elevation model using a machine vision approach.\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation
    - GEOMORPHONS [`output grid`] : Geomorphons
    - THRESHOLD [`floating point number`] : Threshold Angle. Minimum: 0.000000 Default: 1.000000 Flatness threshold angle (degrees).
    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 The radial limit (search radius) [map units].
    - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
    - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_lighting', '8', 'Geomorphons')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Output('GEOMORPHONS', GEOMORPHONS)
        Tool.Set_Option('THRESHOLD', THRESHOLD)
        Tool.Set_Option('RADIUS', RADIUS)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('DLEVEL', DLEVEL)
        return Tool.Execute(Verbose)
    return False




#! /usr/bin/env python

'''
Python Interface to SAGA Tools Library
----------
- Category : Terrain Analysis
- Name     : Slope Stability
- ID       : ta_slope_stability

Description
----------
Tools for slope stability analyses. Developed by Andreas G&uuml;nther, BGR, B2.2
'''

from PySAGA.helper import Tool_Wrapper

def SAFETYFACTOR(
    A=None,
    BMIN=None,
    BMAX=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    FMIN=None,
    FMAX=None,
    G=None,
    H=None,
    FBMIN=None,
    FBMAX=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    FFMIN=None,
    FFMAX=None,
    fI=None, Verbose=2):
    '''
    SAFETYFACTOR
    ----------
    [ta_slope_stability.0]\n
    This tool computes a slope stability (expressed as a factor-of-safety) raster according to the traditional infinite slope model theory (see cf Selby, 1993) The resulting raster represents the ratio of resisting forces/driving forces (fs) on a potential shear plane with fs lesser 1 unstable, fs greater 1 stable. Except for a slope raster (in radians), all input variables can be specified either globally or distributed (through grids). The tool creates a continuous fs raster (values above 10 are truncated), and a binary stability grid with nodata = stable, 1 = unstable (optional).\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radÃ­ans)
    - BMIN [`optional input grid`] : Min thickness grid (m) . A grid representing minimum cell layer thicknesses to potential shear plane (in meters)
    - BMAX [`optional input grid`] : Max thickness grid (m) . A grid representing maximum cell layer thicknesses to potential shear plane (in meters)
    - CMIN [`optional input grid`] : Min saturation grid (-) . A grid representing minimum cell relative water saturation of layer (dimensionless)
    - CMAX [`optional input grid`] : Max saturation grid (-) . A grid representing maximum cell relative water saturation of layer (dimensionless)
    - DMIN [`optional input grid`] : Min friction grid (degree) . A grid representing minimum cell frictional shear strength of layer (in degrees)
    - DMAX [`optional input grid`] : Max friction grid (degree) . A grid representing maximum cell frictional shear strength of layer (in degrees)
    - EMIN [`optional input grid`] : Min density grid (g/cm3). A grid representing minimum cell bulk density of layer (in grams per cubiccentimeters)
    - EMAX [`optional input grid`] : Max density grid (g/cm3). A grid representing maximum cell bulk density of layer (in grams per cubiccentimeters)
    - FMIN [`optional input grid`] : Min cohesion grid (MPa) . A grid representing minimum cell layer cohesion (in Megapascals)
    - FMAX [`optional input grid`] : Max cohesion grid (MPa) . A grid representing maximum cell layer cohesion (in Megapascals)
    - G [`output grid`] : FS values. Resulting factor-of-safety (-) grid
    - H [`output grid`] : FS classes. Resulting stability (0/1) grid
    - FBMIN [`floating point number`] : Min global thickness (m). Default: 1.000000 Constant value if no raster set
    - FBMAX [`floating point number`] : Max global thickness (m). Default: 1.000000 Constant value if no raster set
    - FCMIN [`floating point number`] : Min global saturation (-). Default: 0.000000 Constant value if no raster set
    - FCMAX [`floating point number`] : Max global saturation (-). Default: 0.000000 Constant value if no raster set
    - FDMIN [`floating point number`] : Min global friction (degree). Default: 33.000000 Constant value if no raster set
    - FDMAX [`floating point number`] : Max global friction (degree). Default: 33.000000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FFMIN [`floating point number`] : Min global cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - FFMAX [`floating point number`] : Max global cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - fI [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '0', 'SAFETYFACTOR')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('Bmin', BMIN)
        Tool.Set_Input ('Bmax', BMAX)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Input ('Fmin', FMIN)
        Tool.Set_Input ('Fmax', FMAX)
        Tool.Set_Output('G', G)
        Tool.Set_Output('H', H)
        Tool.Set_Option('fBmin', FBMIN)
        Tool.Set_Option('fBmax', FBMAX)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fFmin', FFMIN)
        Tool.Set_Option('fFmax', FFMAX)
        Tool.Set_Option('fI', fI)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_0(
    A=None,
    BMIN=None,
    BMAX=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    FMIN=None,
    FMAX=None,
    G=None,
    H=None,
    FBMIN=None,
    FBMAX=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    FFMIN=None,
    FFMAX=None,
    fI=None, Verbose=2):
    '''
    SAFETYFACTOR
    ----------
    [ta_slope_stability.0]\n
    This tool computes a slope stability (expressed as a factor-of-safety) raster according to the traditional infinite slope model theory (see cf Selby, 1993) The resulting raster represents the ratio of resisting forces/driving forces (fs) on a potential shear plane with fs lesser 1 unstable, fs greater 1 stable. Except for a slope raster (in radians), all input variables can be specified either globally or distributed (through grids). The tool creates a continuous fs raster (values above 10 are truncated), and a binary stability grid with nodata = stable, 1 = unstable (optional).\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radÃ­ans)
    - BMIN [`optional input grid`] : Min thickness grid (m) . A grid representing minimum cell layer thicknesses to potential shear plane (in meters)
    - BMAX [`optional input grid`] : Max thickness grid (m) . A grid representing maximum cell layer thicknesses to potential shear plane (in meters)
    - CMIN [`optional input grid`] : Min saturation grid (-) . A grid representing minimum cell relative water saturation of layer (dimensionless)
    - CMAX [`optional input grid`] : Max saturation grid (-) . A grid representing maximum cell relative water saturation of layer (dimensionless)
    - DMIN [`optional input grid`] : Min friction grid (degree) . A grid representing minimum cell frictional shear strength of layer (in degrees)
    - DMAX [`optional input grid`] : Max friction grid (degree) . A grid representing maximum cell frictional shear strength of layer (in degrees)
    - EMIN [`optional input grid`] : Min density grid (g/cm3). A grid representing minimum cell bulk density of layer (in grams per cubiccentimeters)
    - EMAX [`optional input grid`] : Max density grid (g/cm3). A grid representing maximum cell bulk density of layer (in grams per cubiccentimeters)
    - FMIN [`optional input grid`] : Min cohesion grid (MPa) . A grid representing minimum cell layer cohesion (in Megapascals)
    - FMAX [`optional input grid`] : Max cohesion grid (MPa) . A grid representing maximum cell layer cohesion (in Megapascals)
    - G [`output grid`] : FS values. Resulting factor-of-safety (-) grid
    - H [`output grid`] : FS classes. Resulting stability (0/1) grid
    - FBMIN [`floating point number`] : Min global thickness (m). Default: 1.000000 Constant value if no raster set
    - FBMAX [`floating point number`] : Max global thickness (m). Default: 1.000000 Constant value if no raster set
    - FCMIN [`floating point number`] : Min global saturation (-). Default: 0.000000 Constant value if no raster set
    - FCMAX [`floating point number`] : Max global saturation (-). Default: 0.000000 Constant value if no raster set
    - FDMIN [`floating point number`] : Min global friction (degree). Default: 33.000000 Constant value if no raster set
    - FDMAX [`floating point number`] : Max global friction (degree). Default: 33.000000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FFMIN [`floating point number`] : Min global cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - FFMAX [`floating point number`] : Max global cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - fI [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '0', 'SAFETYFACTOR')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('Bmin', BMIN)
        Tool.Set_Input ('Bmax', BMAX)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Input ('Fmin', FMIN)
        Tool.Set_Input ('Fmax', FMAX)
        Tool.Set_Output('G', G)
        Tool.Set_Output('H', H)
        Tool.Set_Option('fBmin', FBMIN)
        Tool.Set_Option('fBmax', FBMAX)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fFmin', FFMIN)
        Tool.Set_Option('fFmax', FFMAX)
        Tool.Set_Option('fI', fI)
        return Tool.Execute(Verbose)
    return False

def TOBIA(
    A=None,
    B=None,
    C=None,
    D=None,
    E=None,
    F=None,
    fB=None,
    fC=None, Verbose=2):
    '''
    TOBIA
    ----------
    [ta_slope_stability.1]\n
    This tool computes both a continuous and a categorical TOBIA (Topography Bedding Intersection Angle) Index according to Meentemeyer & Moody (2000) For computation, a slope and a aspect raster (both in radians) determining slope face orientations are required. The categorical TOBIA classifies the alignment of a geological structure to Topography into seven classes:\n
    0) Underdip slope\n
    1) Dip slope\n
    2) Overdip slope\n
    3) Steepened escarpmemt\n
    4) Normal escarpment\n
    5) Subdued escarpment\n
    6) Orthoclinal slope\n
    The continuous TOBIA index ranges from -1 to 1 (parallel orientation)\n
    The structure TOBIA should be calculated with can be set either distributed (through dip direction and dip grids, in degrees!), or globally using integers (dip and dip direction, in degrees!). The tool creates a TOBIA class integer grid, and (optionally) a continuous TOBIA index grid.\n
    Reference: [Meentemeyer R. K., Moody A. (2000). Automated mapping of conformity between topographic and geological surfaces. Computers & Geosciences, 26, 815 - 829](http://www.sciencedirect.com/science/article/pii/S009830040000011X).\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radians)
    - B [`input grid`] : Aspect grid (rad). A aspect angle grid (in radians)
    - C [`optional input grid`] : Dip grid (degrees) . A grid representing the dip of the structure plane (in degrees)
    - D [`optional input grid`] : Dip direction grid (degrees) . A grid representing the dip direction of the structure plane (in degrees)
    - E [`output grid`] : TOBIA classes. Resulting TOBIA classes (1-7) grid
    - F [`output grid`] : TOBIA index. Resulting TOBIA index (-) grid
    - fB [`floating point number`] : Global structure dip (degrees). Default: 45.000000 Constant value if no raster set
    - fC [`floating point number`] : Global structure dip direction (degrees). Default: 90.000000 Constant value if no raster set

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '1', 'TOBIA')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('B', B)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Output('E', E)
        Tool.Set_Output('F', F)
        Tool.Set_Option('fB', fB)
        Tool.Set_Option('fC', fC)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_1(
    A=None,
    B=None,
    C=None,
    D=None,
    E=None,
    F=None,
    fB=None,
    fC=None, Verbose=2):
    '''
    TOBIA
    ----------
    [ta_slope_stability.1]\n
    This tool computes both a continuous and a categorical TOBIA (Topography Bedding Intersection Angle) Index according to Meentemeyer & Moody (2000) For computation, a slope and a aspect raster (both in radians) determining slope face orientations are required. The categorical TOBIA classifies the alignment of a geological structure to Topography into seven classes:\n
    0) Underdip slope\n
    1) Dip slope\n
    2) Overdip slope\n
    3) Steepened escarpmemt\n
    4) Normal escarpment\n
    5) Subdued escarpment\n
    6) Orthoclinal slope\n
    The continuous TOBIA index ranges from -1 to 1 (parallel orientation)\n
    The structure TOBIA should be calculated with can be set either distributed (through dip direction and dip grids, in degrees!), or globally using integers (dip and dip direction, in degrees!). The tool creates a TOBIA class integer grid, and (optionally) a continuous TOBIA index grid.\n
    Reference: [Meentemeyer R. K., Moody A. (2000). Automated mapping of conformity between topographic and geological surfaces. Computers & Geosciences, 26, 815 - 829](http://www.sciencedirect.com/science/article/pii/S009830040000011X).\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radians)
    - B [`input grid`] : Aspect grid (rad). A aspect angle grid (in radians)
    - C [`optional input grid`] : Dip grid (degrees) . A grid representing the dip of the structure plane (in degrees)
    - D [`optional input grid`] : Dip direction grid (degrees) . A grid representing the dip direction of the structure plane (in degrees)
    - E [`output grid`] : TOBIA classes. Resulting TOBIA classes (1-7) grid
    - F [`output grid`] : TOBIA index. Resulting TOBIA index (-) grid
    - fB [`floating point number`] : Global structure dip (degrees). Default: 45.000000 Constant value if no raster set
    - fC [`floating point number`] : Global structure dip direction (degrees). Default: 90.000000 Constant value if no raster set

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '1', 'TOBIA')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('B', B)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Output('E', E)
        Tool.Set_Output('F', F)
        Tool.Set_Option('fB', fB)
        Tool.Set_Option('fC', fC)
        return Tool.Execute(Verbose)
    return False

def SHALSTAB(
    A=None,
    B=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    FMIN=None,
    FMAX=None,
    JMIN=None,
    JMAX=None,
    G=None,
    H=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    FFMIN=None,
    FFMAX=None,
    FJMIN=None,
    FJMAX=None,
    fK=None, Verbose=2):
    '''
    SHALSTAB
    ----------
    [ta_slope_stability.2]\n
    This tool is a realization of the SHALSTAB (Shallow Slope Stability) model from Montgomery & Dietrich (1994). The model computes grid cell critical shallow groundwater recharge values (CR in mm/day) as a measure for relative shallow slope stability, utilizing a simple model that combines a steady-state hydrologic model (a topographic wetness index) to predict groundwater pressures with an infinite slope stability model. For computation, a slope (in radians) and a catchment area (in m2) grid are required. Additionally, information on material density (g/cm3), material friction angle (&deg;), material hydraulic conductivity (m/hr), bulk cohesion (MPa) and depth to potential shear plane (m) are required that can be specified either globally or through grids. The minimum and maximum grids (or global values) specify the range of values from which each soil parameter is sampled. The number of sample runs determines how many values for each soil parameter are randomly taken from the range of values found for each grid cell. Finally, the mean value of the samples taken is calculated (per cell) and used as the soil parameter value in the stability equations. This introduces a probabilistic component in addition to the spatial variability of the soil parameters. If you want to work with static values, enter the same value for minimum and maximum and set the number of samples to one.\n
    The tool produces a continuous CR (mm/day) raster with unconditionally stable cells blanked, and unconditionally unstable cells as CR = 0. Optionally, a classified CR grid can be calculated representing seven stability classes.\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radians)
    - B [`input grid`] : Catchment area grid (m2). A catchment area grid (in square meters)
    - CMIN [`optional input grid`] : Min Density grid (g/cm3). A grid representing minimum material density (in g/cm3)
    - CMAX [`optional input grid`] : Max Density grid (g/cm3). A grid representing maximum material density (in g/cm3)
    - DMIN [`optional input grid`] : Min Hydraulic conductivity grid (m/hr) . A grid representing minimum material hydraulic conductivity (in m/hr)
    - DMAX [`optional input grid`] : Max Hydraulic conductivity grid (m/hr) . A grid representing maximum material hydraulic conductivity (in m/hr)
    - EMIN [`optional input grid`] : Min Thickness grid (m). A grid representing minimum material thickness (in m)
    - EMAX [`optional input grid`] : Max Thickness grid (m). A grid representing maximum material thickness (in m)
    - FMIN [`optional input grid`] : Min Friction angle grid (degree) . A grid representing minimum material friction angle (in degrees)
    - FMAX [`optional input grid`] : Max Friction angle grid (degree) . A grid representing maximum material friction angle (in degrees)
    - JMIN [`optional input grid`] : Min Bulk cohesion grid (MPa) . A grid representing minimum bulk cohesion
    - JMAX [`optional input grid`] : Max Bulk cohesion grid (MPa) . A grid representing maximum bulk cohesion
    - G [`output grid`] : CR values. Resulting critical recharge (m/day) grid
    - H [`output grid`] : CR classes. Classified critical recharge (-) grid
    - FCMIN [`floating point number`] : Global minimum density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FCMAX [`floating point number`] : Global maximum density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FDMIN [`floating point number`] : Global minimum conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FDMAX [`floating point number`] : Global maximum conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FEMIN [`floating point number`] : Global minimum thickness (m). Default: 1.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Global maximum thickness (m). Default: 1.000000 Constant value if no raster set
    - FFMIN [`floating point number`] : Global minimum friction angle (degree). Default: 33.000000 Constant value if no raster set
    - FFMAX [`floating point number`] : Global maximum friction angle (degree). Default: 33.000000 Constant value if no raster set
    - FJMIN [`floating point number`] : Global minimum bulk cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - FJMAX [`floating point number`] : Global maximum bulk cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - fK [`integer number`] : Number of sampling runs. Default: 1 Number of sampling cycles

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '2', 'SHALSTAB')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('B', B)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Input ('Fmin', FMIN)
        Tool.Set_Input ('Fmax', FMAX)
        Tool.Set_Input ('Jmin', JMIN)
        Tool.Set_Input ('Jmax', JMAX)
        Tool.Set_Output('G', G)
        Tool.Set_Output('H', H)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fFmin', FFMIN)
        Tool.Set_Option('fFmax', FFMAX)
        Tool.Set_Option('fJmin', FJMIN)
        Tool.Set_Option('fJmax', FJMAX)
        Tool.Set_Option('fK', fK)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_2(
    A=None,
    B=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    FMIN=None,
    FMAX=None,
    JMIN=None,
    JMAX=None,
    G=None,
    H=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    FFMIN=None,
    FFMAX=None,
    FJMIN=None,
    FJMAX=None,
    fK=None, Verbose=2):
    '''
    SHALSTAB
    ----------
    [ta_slope_stability.2]\n
    This tool is a realization of the SHALSTAB (Shallow Slope Stability) model from Montgomery & Dietrich (1994). The model computes grid cell critical shallow groundwater recharge values (CR in mm/day) as a measure for relative shallow slope stability, utilizing a simple model that combines a steady-state hydrologic model (a topographic wetness index) to predict groundwater pressures with an infinite slope stability model. For computation, a slope (in radians) and a catchment area (in m2) grid are required. Additionally, information on material density (g/cm3), material friction angle (&deg;), material hydraulic conductivity (m/hr), bulk cohesion (MPa) and depth to potential shear plane (m) are required that can be specified either globally or through grids. The minimum and maximum grids (or global values) specify the range of values from which each soil parameter is sampled. The number of sample runs determines how many values for each soil parameter are randomly taken from the range of values found for each grid cell. Finally, the mean value of the samples taken is calculated (per cell) and used as the soil parameter value in the stability equations. This introduces a probabilistic component in addition to the spatial variability of the soil parameters. If you want to work with static values, enter the same value for minimum and maximum and set the number of samples to one.\n
    The tool produces a continuous CR (mm/day) raster with unconditionally stable cells blanked, and unconditionally unstable cells as CR = 0. Optionally, a classified CR grid can be calculated representing seven stability classes.\n
    Arguments
    ----------
    - A [`input grid`] : Slope grid (rad). A slope angle grid (in radians)
    - B [`input grid`] : Catchment area grid (m2). A catchment area grid (in square meters)
    - CMIN [`optional input grid`] : Min Density grid (g/cm3). A grid representing minimum material density (in g/cm3)
    - CMAX [`optional input grid`] : Max Density grid (g/cm3). A grid representing maximum material density (in g/cm3)
    - DMIN [`optional input grid`] : Min Hydraulic conductivity grid (m/hr) . A grid representing minimum material hydraulic conductivity (in m/hr)
    - DMAX [`optional input grid`] : Max Hydraulic conductivity grid (m/hr) . A grid representing maximum material hydraulic conductivity (in m/hr)
    - EMIN [`optional input grid`] : Min Thickness grid (m). A grid representing minimum material thickness (in m)
    - EMAX [`optional input grid`] : Max Thickness grid (m). A grid representing maximum material thickness (in m)
    - FMIN [`optional input grid`] : Min Friction angle grid (degree) . A grid representing minimum material friction angle (in degrees)
    - FMAX [`optional input grid`] : Max Friction angle grid (degree) . A grid representing maximum material friction angle (in degrees)
    - JMIN [`optional input grid`] : Min Bulk cohesion grid (MPa) . A grid representing minimum bulk cohesion
    - JMAX [`optional input grid`] : Max Bulk cohesion grid (MPa) . A grid representing maximum bulk cohesion
    - G [`output grid`] : CR values. Resulting critical recharge (m/day) grid
    - H [`output grid`] : CR classes. Classified critical recharge (-) grid
    - FCMIN [`floating point number`] : Global minimum density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FCMAX [`floating point number`] : Global maximum density (g/cm3). Default: 1.600000 Constant value if no raster set
    - FDMIN [`floating point number`] : Global minimum conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FDMAX [`floating point number`] : Global maximum conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FEMIN [`floating point number`] : Global minimum thickness (m). Default: 1.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Global maximum thickness (m). Default: 1.000000 Constant value if no raster set
    - FFMIN [`floating point number`] : Global minimum friction angle (degree). Default: 33.000000 Constant value if no raster set
    - FFMAX [`floating point number`] : Global maximum friction angle (degree). Default: 33.000000 Constant value if no raster set
    - FJMIN [`floating point number`] : Global minimum bulk cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - FJMAX [`floating point number`] : Global maximum bulk cohesion (MPa). Default: 0.000000 Constant value if no raster set
    - fK [`integer number`] : Number of sampling runs. Default: 1 Number of sampling cycles

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '2', 'SHALSTAB')
    if Tool.is_Okay():
        Tool.Set_Input ('A', A)
        Tool.Set_Input ('B', B)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Input ('Fmin', FMIN)
        Tool.Set_Input ('Fmax', FMAX)
        Tool.Set_Input ('Jmin', JMIN)
        Tool.Set_Input ('Jmax', JMAX)
        Tool.Set_Output('G', G)
        Tool.Set_Output('H', H)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fFmin', FFMIN)
        Tool.Set_Option('fFmax', FFMAX)
        Tool.Set_Option('fJmin', FJMIN)
        Tool.Set_Option('fJmax', FJMAX)
        Tool.Set_Option('fK', fK)
        return Tool.Execute(Verbose)
    return False

def WETNESS(
    DEM=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    F=None,
    G=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    fH=None,
    METHOD=None,
    PREPROC=None, Verbose=2):
    '''
    WETNESS
    ----------
    [ta_slope_stability.3]\n
    This tool calculates a topographic wetness index (TWI) following Montgomery & Dietrich (1994) that can be used to estimate the degree of saturation of unconsolidated, permeable materials above (more or less) impermeable bedrock. In contrast to the common TOPMODEL (Beven & Kirkby, 1979) - based TWI, this index differs in such that it considers hydraulic conductivity to be constant in a soil mantle overlying relatively impermeable bedrock. Also, it uses the sine of the slope rather than its tangens, which is more correct and significantly matters for steeper slopes that give raise to landslides. For computation, a slope (in radians) and a catchment area (in m2) grid are required. Additionally, information on groundwater recharge (m/hr), material hydraulic conductivity (m/hr), and depth to potential shear plane (m) are required that can be specified either globally or through grids. The tool produces a continuous wetness index (-) where cells with WI values > 1 (overland flow) set to 1, and optionally creates a classified WI grid rendering three saturation classes:.\n
    0): Low moisture (WI smaller 0.1)\n
    1): Partially wet (0.1 smaller WI smaller 1)\n
    2): Saturation zone (WI larger 1)\n
    References:\n
    [Beven, K.J., Kirkby, M.J. (1979) A physically-based variable contributing area model of basin hydrology. Hydrology Science Bulletin, 24, 43-69.](http://www.tandfonline.com/doi/abs/10.1080/02626667909491834).\n
    [Montgomery D. R., Dietrich, W. E. (1994) A physically based model for the topographic control on shallow landsliding. Water Resources Research, 30, 1153-1171.](http://www.agu.org/pubs/crossref/1994/93WR02979.shtml).\n
    Arguments
    ----------
    - DEM [`input grid`] : DEM. A DEM
    - CMIN [`optional input grid`] : Min hydraulic conductivity grid (m/hr) . A grid representing minimum material hydraulic conductivity (in m/hr)
    - CMAX [`optional input grid`] : Max hydraulic conductivity grid (m/hr) . A grid representing maximum material hydraulic conductivity (in m/hr)
    - DMIN [`optional input grid`] : Min groundwater recharge grid (m/hr) . A grid representing minimum groundwater recharge (in m/hr)
    - DMAX [`optional input grid`] : Max groundwater recharge grid (m/hr) . A grid representing maximum groundwater recharge (in m/hr)
    - EMIN [`optional input grid`] : Min material depth grid (m). A grid representing minimum depth to potential shear plane (in m)
    - EMAX [`optional input grid`] : Max material depth grid (m). A grid representing maximum depth to potential shear plane (in m)
    - F [`output grid`] : WI values. Resulting wetness index (-) grid
    - G [`output grid`] : WI classes. Classified wetness (-) grid
    - FCMIN [`floating point number`] : Min global material conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FCMAX [`floating point number`] : Max global material conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FDMIN [`floating point number`] : Min global groundwater recharge (m/hr). Default: 0.001000 Constant value if no raster set
    - FDMAX [`floating point number`] : Max global groundwater recharge (m/hr). Default: 0.001000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global material depth (m). Default: 1.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global material depth (m). Default: 1.000000 Constant value if no raster set
    - fH [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles
    - METHOD [`choice`] : Catchment Area Calculation. Available Choices: [0] Deterministic 8 [1] Rho 8 [2] Braunschweiger Reliefmodell [3] Deterministic Infinity [4] Multiple Flow Direction [5] Multiple Triangular Flow Direction Default: 4
    - PREPROC [`boolean`] : Preprocessing. Default: 0

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '3', 'WETNESS')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Output('F', F)
        Tool.Set_Output('G', G)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fH', fH)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('PREPROC', PREPROC)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_3(
    DEM=None,
    CMIN=None,
    CMAX=None,
    DMIN=None,
    DMAX=None,
    EMIN=None,
    EMAX=None,
    F=None,
    G=None,
    FCMIN=None,
    FCMAX=None,
    FDMIN=None,
    FDMAX=None,
    FEMIN=None,
    FEMAX=None,
    fH=None,
    METHOD=None,
    PREPROC=None, Verbose=2):
    '''
    WETNESS
    ----------
    [ta_slope_stability.3]\n
    This tool calculates a topographic wetness index (TWI) following Montgomery & Dietrich (1994) that can be used to estimate the degree of saturation of unconsolidated, permeable materials above (more or less) impermeable bedrock. In contrast to the common TOPMODEL (Beven & Kirkby, 1979) - based TWI, this index differs in such that it considers hydraulic conductivity to be constant in a soil mantle overlying relatively impermeable bedrock. Also, it uses the sine of the slope rather than its tangens, which is more correct and significantly matters for steeper slopes that give raise to landslides. For computation, a slope (in radians) and a catchment area (in m2) grid are required. Additionally, information on groundwater recharge (m/hr), material hydraulic conductivity (m/hr), and depth to potential shear plane (m) are required that can be specified either globally or through grids. The tool produces a continuous wetness index (-) where cells with WI values > 1 (overland flow) set to 1, and optionally creates a classified WI grid rendering three saturation classes:.\n
    0): Low moisture (WI smaller 0.1)\n
    1): Partially wet (0.1 smaller WI smaller 1)\n
    2): Saturation zone (WI larger 1)\n
    References:\n
    [Beven, K.J., Kirkby, M.J. (1979) A physically-based variable contributing area model of basin hydrology. Hydrology Science Bulletin, 24, 43-69.](http://www.tandfonline.com/doi/abs/10.1080/02626667909491834).\n
    [Montgomery D. R., Dietrich, W. E. (1994) A physically based model for the topographic control on shallow landsliding. Water Resources Research, 30, 1153-1171.](http://www.agu.org/pubs/crossref/1994/93WR02979.shtml).\n
    Arguments
    ----------
    - DEM [`input grid`] : DEM. A DEM
    - CMIN [`optional input grid`] : Min hydraulic conductivity grid (m/hr) . A grid representing minimum material hydraulic conductivity (in m/hr)
    - CMAX [`optional input grid`] : Max hydraulic conductivity grid (m/hr) . A grid representing maximum material hydraulic conductivity (in m/hr)
    - DMIN [`optional input grid`] : Min groundwater recharge grid (m/hr) . A grid representing minimum groundwater recharge (in m/hr)
    - DMAX [`optional input grid`] : Max groundwater recharge grid (m/hr) . A grid representing maximum groundwater recharge (in m/hr)
    - EMIN [`optional input grid`] : Min material depth grid (m). A grid representing minimum depth to potential shear plane (in m)
    - EMAX [`optional input grid`] : Max material depth grid (m). A grid representing maximum depth to potential shear plane (in m)
    - F [`output grid`] : WI values. Resulting wetness index (-) grid
    - G [`output grid`] : WI classes. Classified wetness (-) grid
    - FCMIN [`floating point number`] : Min global material conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FCMAX [`floating point number`] : Max global material conductivity (m/hr). Default: 2.700000 Constant value if no raster set
    - FDMIN [`floating point number`] : Min global groundwater recharge (m/hr). Default: 0.001000 Constant value if no raster set
    - FDMAX [`floating point number`] : Max global groundwater recharge (m/hr). Default: 0.001000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global material depth (m). Default: 1.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global material depth (m). Default: 1.000000 Constant value if no raster set
    - fH [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles
    - METHOD [`choice`] : Catchment Area Calculation. Available Choices: [0] Deterministic 8 [1] Rho 8 [2] Braunschweiger Reliefmodell [3] Deterministic Infinity [4] Multiple Flow Direction [5] Multiple Triangular Flow Direction Default: 4
    - PREPROC [`boolean`] : Preprocessing. Default: 0

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '3', 'WETNESS')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('Cmin', CMIN)
        Tool.Set_Input ('Cmax', CMAX)
        Tool.Set_Input ('Dmin', DMIN)
        Tool.Set_Input ('Dmax', DMAX)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Output('F', F)
        Tool.Set_Output('G', G)
        Tool.Set_Option('fCmin', FCMIN)
        Tool.Set_Option('fCmax', FCMAX)
        Tool.Set_Option('fDmin', FDMIN)
        Tool.Set_Option('fDmax', FDMAX)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('fH', fH)
        Tool.Set_Option('METHOD', METHOD)
        Tool.Set_Option('PREPROC', PREPROC)
        return Tool.Execute(Verbose)
    return False

def WEDGEFAIL(
    DEM=None,
    C=None,
    D=None,
    EMIN=None,
    EMAX=None,
    F=None,
    fC=None,
    fD=None,
    FEMIN=None,
    FEMAX=None,
    ff=None,
    fI=None,
    METHOD=None, Verbose=2):
    '''
    WEDGEFAIL
    ----------
    [ta_slope_stability.4]\n
    This tool determines terrain elements where failure (slide- or topple movements) on geological discontinuies are kinematically possible through the spatial application of common frictional feasibility criteria (G&uuml;nther et al. 2012 and references therein). Both the orientation of slope elements specified through aspect- and dip grids (in radians) are required together with the orientation of one planar structure defined through global- or grid dip direction and dip data, or two planar structures defined by plunge direction and plunge information of their intersection line (in degrees). The shear strength of the discontinuities is specified using global or grid-based friction angle data. Optionally, a cone value can be set allowing for some variance in discontinuity dip orientations. The tool operates in slide (testing for plane and wedge sliding) or topple (testing for plane and wedge toppling) modes.\n
    Arguments
    ----------
    - DEM [`input grid`] : DEM. A DEM
    - C [`optional input grid`] : Dip/Plunge direction grid (degree) . A dip- or plunge direction grid (in degrees)
    - D [`optional input grid`] : Dip/Plunge grid (degree) . A dip- or plunge grid (in degrees)
    - EMIN [`optional input grid`] : Min friction angle grid (degree) . A minimum discontinuity friction angle grid (in degrees)
    - EMAX [`optional input grid`] : Max friction angle grid (degree) . A maximum discontinuity friction angle grid (in degrees)
    - F [`output grid`] : Failures. Resulting failure cells (-) grid
    - fC [`floating point number`] : Global dip/plunge direction (degree). Default: 0.000000 Constant value if no raster set
    - fD [`floating point number`] : Global dip/plunge (degree). Default: 35.000000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global friction angle (degree). Default: 35.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global friction angle (degree). Default: 35.000000 Constant value if no raster set
    - ff [`integer number`] : Cone radius (degree). Default: 0 Radius of optional cone variance (in degrees)
    - fI [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles
    - METHOD [`choice`] : Mode. Available Choices: [0] Slide [1] Topple Default: 0 Set failure mode

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '4', 'WEDGEFAIL')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Output('F', F)
        Tool.Set_Option('fC', fC)
        Tool.Set_Option('fD', fD)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('ff', ff)
        Tool.Set_Option('fI', fI)
        Tool.Set_Option('METHOD', METHOD)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_4(
    DEM=None,
    C=None,
    D=None,
    EMIN=None,
    EMAX=None,
    F=None,
    fC=None,
    fD=None,
    FEMIN=None,
    FEMAX=None,
    ff=None,
    fI=None,
    METHOD=None, Verbose=2):
    '''
    WEDGEFAIL
    ----------
    [ta_slope_stability.4]\n
    This tool determines terrain elements where failure (slide- or topple movements) on geological discontinuies are kinematically possible through the spatial application of common frictional feasibility criteria (G&uuml;nther et al. 2012 and references therein). Both the orientation of slope elements specified through aspect- and dip grids (in radians) are required together with the orientation of one planar structure defined through global- or grid dip direction and dip data, or two planar structures defined by plunge direction and plunge information of their intersection line (in degrees). The shear strength of the discontinuities is specified using global or grid-based friction angle data. Optionally, a cone value can be set allowing for some variance in discontinuity dip orientations. The tool operates in slide (testing for plane and wedge sliding) or topple (testing for plane and wedge toppling) modes.\n
    Arguments
    ----------
    - DEM [`input grid`] : DEM. A DEM
    - C [`optional input grid`] : Dip/Plunge direction grid (degree) . A dip- or plunge direction grid (in degrees)
    - D [`optional input grid`] : Dip/Plunge grid (degree) . A dip- or plunge grid (in degrees)
    - EMIN [`optional input grid`] : Min friction angle grid (degree) . A minimum discontinuity friction angle grid (in degrees)
    - EMAX [`optional input grid`] : Max friction angle grid (degree) . A maximum discontinuity friction angle grid (in degrees)
    - F [`output grid`] : Failures. Resulting failure cells (-) grid
    - fC [`floating point number`] : Global dip/plunge direction (degree). Default: 0.000000 Constant value if no raster set
    - fD [`floating point number`] : Global dip/plunge (degree). Default: 35.000000 Constant value if no raster set
    - FEMIN [`floating point number`] : Min global friction angle (degree). Default: 35.000000 Constant value if no raster set
    - FEMAX [`floating point number`] : Max global friction angle (degree). Default: 35.000000 Constant value if no raster set
    - ff [`integer number`] : Cone radius (degree). Default: 0 Radius of optional cone variance (in degrees)
    - fI [`integer number`] : Parameter sampling runs. Default: 1 Number of sampling cycles
    - METHOD [`choice`] : Mode. Available Choices: [0] Slide [1] Topple Default: 0 Set failure mode

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '4', 'WEDGEFAIL')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Input ('Emin', EMIN)
        Tool.Set_Input ('Emax', EMAX)
        Tool.Set_Output('F', F)
        Tool.Set_Option('fC', fC)
        Tool.Set_Option('fD', fD)
        Tool.Set_Option('fEmin', FEMIN)
        Tool.Set_Option('fEmax', FEMAX)
        Tool.Set_Option('ff', ff)
        Tool.Set_Option('fI', fI)
        Tool.Set_Option('METHOD', METHOD)
        return Tool.Execute(Verbose)
    return False

def ANGMAP(
    DEM=None,
    C=None,
    D=None,
    E=None,
    F=None,
    G=None,
    fB=None,
    fC=None, Verbose=2):
    '''
    ANGMAP
    ----------
    [ta_slope_stability.5]\n
    This tool computes the acute angle raster between the topographic surface defined by slope and aspect rasters internally derived from input elevation raster, and a structural plane defined by diop direction- and dip grids. Optionally, the dip direction and dip of the cutting line linears between the two planes can be calculated\n
    Reference: [G&uuml;nther, A. (2003). SLOPEMAP: programs for automated mapping of geometrical and kinematical properties of hard rock hill slopes. Computers & Geosciences, 29, 865 - 875](http://www.sciencedirect.com/science/article/pii/S0098300403000864).\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation. A Digital Elvation Model (DEM)
    - C [`optional input grid`] : Dip grid (degrees) . A grid representing the dip of the structure plane (in degrees)
    - D [`optional input grid`] : Dip direction grid (degrees) . A grid representing the dip direction of the structure plane (in degrees)
    - E [`output grid`] : Angle. Acute angle (degrees) grid
    - F [`output grid`] : CL dipdir. Dip direction cutting line (degrees)
    - G [`output grid`] : CL dip. Dip cutting line (degrees)
    - fB [`floating point number`] : Global structure dip (degrees). Default: 45.000000 Constant value if no raster set
    - fC [`floating point number`] : Global structure dip direction (degrees). Default: 90.000000 Constant value if no raster set

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '5', 'ANGMAP')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Output('E', E)
        Tool.Set_Output('F', F)
        Tool.Set_Output('G', G)
        Tool.Set_Option('fB', fB)
        Tool.Set_Option('fC', fC)
        return Tool.Execute(Verbose)
    return False

def run_tool_ta_slope_stability_5(
    DEM=None,
    C=None,
    D=None,
    E=None,
    F=None,
    G=None,
    fB=None,
    fC=None, Verbose=2):
    '''
    ANGMAP
    ----------
    [ta_slope_stability.5]\n
    This tool computes the acute angle raster between the topographic surface defined by slope and aspect rasters internally derived from input elevation raster, and a structural plane defined by diop direction- and dip grids. Optionally, the dip direction and dip of the cutting line linears between the two planes can be calculated\n
    Reference: [G&uuml;nther, A. (2003). SLOPEMAP: programs for automated mapping of geometrical and kinematical properties of hard rock hill slopes. Computers & Geosciences, 29, 865 - 875](http://www.sciencedirect.com/science/article/pii/S0098300403000864).\n
    Arguments
    ----------
    - DEM [`input grid`] : Elevation. A Digital Elvation Model (DEM)
    - C [`optional input grid`] : Dip grid (degrees) . A grid representing the dip of the structure plane (in degrees)
    - D [`optional input grid`] : Dip direction grid (degrees) . A grid representing the dip direction of the structure plane (in degrees)
    - E [`output grid`] : Angle. Acute angle (degrees) grid
    - F [`output grid`] : CL dipdir. Dip direction cutting line (degrees)
    - G [`output grid`] : CL dip. Dip cutting line (degrees)
    - fB [`floating point number`] : Global structure dip (degrees). Default: 45.000000 Constant value if no raster set
    - fC [`floating point number`] : Global structure dip direction (degrees). Default: 90.000000 Constant value if no raster set

    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
    Returns
    ----------
    `boolean` : `True` on success, `False` on failure.
    '''
    Tool = Tool_Wrapper('ta_slope_stability', '5', 'ANGMAP')
    if Tool.is_Okay():
        Tool.Set_Input ('DEM', DEM)
        Tool.Set_Input ('C', C)
        Tool.Set_Input ('D', D)
        Tool.Set_Output('E', E)
        Tool.Set_Output('F', F)
        Tool.Set_Output('G', G)
        Tool.Set_Option('fB', fB)
        Tool.Set_Option('fC', fC)
        return Tool.Execute(Verbose)
    return False

